@@ -1,13 +1,24 @@
 #!/usr/bin/perl
 
-# Copyright (C) 2001-2003 Curt Mills, WE7U
+# Copyright (C) 2001-2006 Curt Mills, WE7U
 # Released to the public domain.
 #
-# $Id: inf2geo.pl,v 1.4 2003/08/21 18:01:09 we7u Exp $
+# $Id: inf2geo.pl,v 1.8 2007/02/06 14:55:34 we7u Exp $
+#
+#
+# Invoke this script against one or more info files by typing:
+#
+#       inf2geo.pl filename.inf
+# -or-
+#       inf2geo.pl *.inf
+#
+# To process all .inf files in that directory.
+#
 #
 # Read in .inf file (from Ui-View)
 # Convert the lat/long coordinates into dd.dddd format
-# Get the image extents via "identify -ping filename"
+# Get the image extents via "identify -ping filename" or
+# "gm identify -ping filename".
 # Write out the .geo file
 # Note that this program assumes (and converts to)
 # lower-case for the filename.
@@ -23,11 +34,26 @@
 use IO::File;
 
 #go through every filename passed to this script
-foreach my $file (@ARGV) {
-    print "*** $file ***\n";
+
+#printf("ARGV:%d\n",$#ARGV);
+
+if ($#ARGV == -1) {
+    # No filenames on the command line
+    printf("\n\n\nNo filenames specified.  Invoke this script against one\n");
+    printf("or more .inf files by typing:\n\n");
+    printf("        inf2geo.pl filename.inf\n");
+    printf("-or-\n");
+    printf("        inf2geo.pl *.inf\n\n");
+    printf("To process all .inf files in that directory.\n\n");
+    exit;
+}
+else {
+    foreach my $file (@ARGV) {
+        print "*** $file ***\n";
     
-    #make a geo of this file
-    makeGeo ($file);
+        #make a geo of this file
+        makeGeo ($file);
+    }
     
 }
 
@@ -93,6 +119,9 @@ sub makeGeo {
     # test.gif GIF 1148x830+0+0 PseudoClass 256c Palette 8-bit 48kb 0.4u 0:01
     # in later versions of ImageMagick.
     #
+    # GraphicsMagick returns a string like this:
+    # i4-mo.gif GIF 1020x581+0+0 PseudoClass 256c 8-bit 475.8k 0.050u 0:01
+    #
 
     chomp($string);
     $string =~ s/.*\s(\d+x\d+).*/$1/;    # Grab the 1148x830 portion
@@ -186,21 +215,28 @@ sub findImageFile {
     $filename = shift;
     @extensions = ("gif", "bmp", "jpg", "png", "emf");
     foreach $xtn (@extensions) {
-	$try_filename = "$filename.$xtn";
-#	print "Looking for $try_filename\n";
-	$string = `identify -ping $try_filename 2>/dev/null`;
-	if ($string ne "") {
-	    $filename = $try_filename;
-	    $image_size = $string;
-	}
+        $try_filename = "$filename.$xtn";
+#        print "Looking for $try_filename\n";
+
+        # Try GraphicsMagick's 'gm' first
+        $string = `gm identify -ping $try_filename 2>/dev/null`;
+        if ($string eq "") {
+            # Else try ImageMagick's 'identify'
+            $string = `identify -ping $try_filename 2>/dev/null`;
+        }
+        if ($string ne "") {
+            # Found the file and GM or IM
+            $filename = $try_filename;
+            $image_size = $string;
+        }
     }
     if ($image_size eq "") {
-	print "Image file not found for $filename, maybe be a case problem\n" ;
-	return;
+        print "Image file not found for $filename, may be be a case problem\n" ;
+        print "or a problem finding GraphicsMagick's 'gm' or ImageMagick's 'identify' program\n";
+        print "Make sure that either GraphicsMagick or ImageMagick is installed.\n";
+        return;
     }
     
     print "Found this image: $image_size\n";
     return ($filename, $image_size);
 }
-
-
