@@ -1,9 +1,9 @@
 /*
- * $Id: alert.h,v 1.24 2005/10/20 20:12:59 gstueve Exp $
+ * $Id: alert.h,v 1.27 2007/01/03 19:39:07 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2005  The Xastir Group
+ * Copyright (C) 2000-2007  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -87,7 +87,7 @@ extern int alert_active(alert_entry *alert, alert_match_level match_level);
 extern int alert_display_request(void);
 extern int alert_on_screen(void);
 extern int alert_redraw_on_update;
-extern int alert_expire(void);
+extern int alert_expire(int curr_sec);
 extern void alert_build_list(Message *fill);
 extern struct hashtable_itr *create_wx_alert_iterator(void);
 extern alert_entry *get_next_wx_alert(struct hashtable_itr *iterator);
