@@ -1,9 +1,9 @@
 /*
- * $Id: bulletin_gui.c,v 1.34 2005/10/02 06:26:49 we7u Exp $
+ * $Id: bulletin_gui.c,v 1.39 2007/02/27 23:19:08 gstueve Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2005  The Xastir Group
+ * Copyright (C) 2000-2007  The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,8 +22,10 @@
  * Look at the README for more information on the program.
  */
 
-
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif  // HAVE_CONFIG_H
+
 #include "snprintf.h"
 
 #include <stdio.h>
@@ -235,12 +237,6 @@ void bulletin_data_add(char *call_sign, char *from_call, char *data,
         char *seq, char type, char from) {
     int distance = -1;
 
-    // Update the View->Bulletins dialog if it's up
-    bulletin_message(from_call,
-        call_sign,
-        data,
-        sec_now());
-
     // Add to the message database
     (void)msg_data_add(call_sign,
         from_call,
@@ -300,6 +296,12 @@ void bulletin_data_add(char *call_sign, char *from_call, char *data,
 //            fprintf(stderr,", but distance didn't work out!\n");
         }
     }
+    // Update the View->Bulletins dialog if it's up
+    bulletin_message(from_call,
+        call_sign,
+        data,
+        sec_now());
+
 }
 
 
@@ -453,13 +455,13 @@ static void find_zero_position_bulletins(void) {
 // range.  If any found, it updates the Bulletins dialog.
 time_t last_bulletin_check = (time_t)0l;
 
-void check_for_new_bulletins(void) {
+void check_for_new_bulletins(int curr_sec) {
 
     // Check every 15 seconds max
-    if ( (last_bulletin_check + 15) > sec_now() ) {
+    if ( (last_bulletin_check + 15) > curr_sec ) {
         return;
     }
-    last_bulletin_check = sec_now();
+    last_bulletin_check = curr_sec;
 
     // Look first to see if we might be able to fill in positions on
     // any older bulletins, then cause a popup for those that fit
@@ -475,7 +477,7 @@ void check_for_new_bulletins(void) {
 
     // Enough time passed since most recent bulletin?  Need to have
     // enough time to perhaps fill in a distance for each bulletin.
-    if ( (last_new_bulletin_time + 15) > sec_now() ) {
+    if ( (last_new_bulletin_time + 15) > curr_sec ) {
         //fprintf(stderr,"Not enough time has passed\n");
         return;
     }
