@@ -1,5 +1,5 @@
 /*
- * $Id: main.h,v 1.97 2007/01/03 19:39:10 we7u Exp $
+ * $Id: main.h,v 1.100 2007/08/15 17:41:52 gstueve Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
@@ -133,6 +133,7 @@ extern int serial_char_pacing;  // Inter-character delay in ms.
 extern int disable_all_maps;
 extern int re_sort_maps;
 extern Widget trackme_button;
+extern Widget CAD_close_polygon_menu_item;
 extern int debug_level;
 extern int my_position_valid;
 extern int using_gps_position;
@@ -249,9 +250,9 @@ extern What_to_display Display_;
 
 extern int currently_selected_stations;
 extern int currently_selected_stations_save;
-extern int colors[256];
+extern Pixel colors[256];
 #define MAX_TRAIL_COLORS 32
-extern int trail_colors[MAX_TRAIL_COLORS];
+extern Pixel trail_colors[MAX_TRAIL_COLORS];
 extern int current_trail_color;
 extern int english_units;
 extern int do_dbstatus;
@@ -381,7 +382,15 @@ extern void busy_cursor(Widget w);
 extern void pos_dialog(Widget w);
 extern int create_image(Widget w);
 extern void draw_tiger_map (Widget w, char *filenm, int destination_pixmap, int nocache);
-extern void draw_WMS_map (Widget w, char *filenm, int destination_pixmap, char *URL, int do_check_trans, unsigned long trans_color, int nocache);
+
+typedef struct _transparent_color_record{
+    unsigned long trans_color;
+    struct _transparent_color_record *next;
+} transparent_color_record;
+
+extern int check_trans (XColor c, transparent_color_record *c_trans_color_head);
+
+extern void draw_WMS_map (Widget w, char *filenm, int destination_pixmap, char *URL, transparent_color_record *c_trans_color_head, int nocache);
 
 extern void locate_gui_init(void);
 extern void geocoder_gui_init(void);
