@@ -1,5 +1,5 @@
 /* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
- * $Id: map_geo.c,v 1.82 2007/03/06 21:58:51 we7u Exp $
+ * $Id: map_geo.c,v 1.88 2007/08/31 12:20:53 gstueve Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
@@ -140,9 +140,44 @@
 #include "leak_detection.h"
 
 
-
-extern int npoints;		/* tsk tsk tsk -- globals */
-extern int mag;
+int check_interrupt( 
+#ifdef HAVE_MAGICK
+			Image *image, ImageInfo *image_info, ExceptionInfo *exception, 
+#else // HAVE_MAGICK
+			XImage *xi,
+#endif // HAVE_MAGICK
+			Widget *da, Pixmap *pixmap, 
+			GC *gc, unsigned long screen_width, unsigned long screen_height)
+{
+    HandlePendingEvents(app_context);
+    if (interrupt_drawing_now) {
+#ifdef HAVE_MAGICK
+        if (image) 
+            DestroyImage(image);
+        if (image_info)
+            DestroyImageInfo(image_info);
+ #else   // HAVE_MAGICK
+    if (xi)
+        XDestroyImage (xi);
+#endif // HAVE_MAGICK
+        // Update to screen
+        (void)XCopyArea(XtDisplay(*da),
+            *pixmap,
+            XtWindow(*da),
+            *gc,
+            0,
+            0,
+            (unsigned int)screen_width,
+            (unsigned int)screen_height,
+            0,
+            0);
+#ifdef HAVE_MAGICK
+       DestroyExceptionInfo(exception);
+#endif // HAVE_MAGICK
+         return(~0);
+    } else
+	return(0);
+}
 
 void draw_geo_image_map (Widget w, char *dir, char *filenm, 
     alert_entry *alert, u_char alert_color, int destination_pixmap,
@@ -152,6 +187,53 @@ void draw_geo_image_map (Widget w, char *dir, char *filenm,
 
 
 
+/*  typedef struct _transparent_color_record{
+        unsigned long trans_color;
+        struct _transparent_color_record *next;
+    } transparent_color_record;
+*/
+    // Pointer to head of transparent color linked list.
+    transparent_color_record *trans_color_head = NULL;
+
+
+
+
+
+    // Empty out the linked list containing transparent colors
+    void empty_trans_color_list(void) {
+        transparent_color_record *p;
+
+        while (trans_color_head != NULL) {
+            p = trans_color_head;
+            trans_color_head = p->next;
+            free(p);
+        }
+    }
+
+
+
+
+
+    // Add a new transparent color to the linked list
+    void new_trans_color(unsigned long trans_color) {
+        transparent_color_record *p;
+
+//fprintf(stderr,"New transparent color: %lx\n", trans_color);
+
+        p = (transparent_color_record *)malloc( sizeof(transparent_color_record) );
+
+        // Fill in value
+        p->trans_color = trans_color;
+
+        // Link it to transparent color list
+        p->next = trans_color_head;
+        trans_color_head = p;
+    }
+ 
+
+
+
+
 /********************(**********************************************
 * check_trans()
 *
@@ -161,16 +243,20 @@ void draw_geo_image_map (Widget w, char *dir, char *filenm,
 * ok to use IM calls.
 ******************************************(************************/
 
-int check_trans (XColor c, unsigned long c_trans_color) {
+int check_trans (XColor c, transparent_color_record *c_trans_color_head) {
+    transparent_color_record *p = c_trans_color_head;
+
     //    fprintf (stderr, "pix = %li,%lx, chk = %li,%lx.\n",c.pixel,c.pixel,c_trans_color,c_trans_color);
-    // need to load an array from the geo file of colors to zap
-    // for now, just a static list to test
+    // A linked list from the geo file of colors to zap.
 
     //    if ( c.pixel == (unsigned long) 0x000000 ) {
     //    return 1; // black background
     //}
-    if ( c.pixel == c_trans_color ) {
-        return 1;
+    while (p) {
+        if ( c.pixel == p->trans_color ) {
+            return 1;
+        }
+        p = p->next;
     }
 
     return 0; // everything else is OK to draw
@@ -559,8 +645,7 @@ void draw_geo_image_map (Widget w,
 #ifdef FUZZYRASTER
     int rasterfuzz = 3;    // ratio to skip 
 #endif //FUZZYRASTER
-    int do_check_trans = 0;  // do we bother checking for transparent colors
-    unsigned long trans_color;    // what color to zap
+    unsigned long temp_trans_color;    // what color to zap
     int trans_skip = 0;  // skip transparent pixel
     int crop_x1=0, crop_x2=0, crop_y1=0, crop_y2=0; // pixel crop box
     int do_crop = 0;     // do we crop pixels
@@ -572,6 +657,7 @@ void draw_geo_image_map (Widget w,
 #ifdef HAVE_MAGICK
   #ifdef USE_MAP_CACHE 
     int map_cache_return;
+    char *cache_file_id;
   #endif  // USE_MAP_CACHE
 #endif  // HAVE_MAGICK
 
@@ -599,6 +685,11 @@ void draw_geo_image_map (Widget w,
 
 
     // Read the .geo file to find out map filename and tiepoint info
+
+    // Empty the transparent color list before we start reading in a
+    // new .geo file.
+    empty_trans_color_list();
+
     n_tp = 0;
     geo_datum[0]      = '\0';
     geo_projection[0] = '\0';
@@ -723,17 +814,17 @@ void draw_geo_image_map (Widget w,
                 // need to make this read a list of colors to zap
                 // out.  Use 32-bit unsigned values, so we can
                 // handle 32-bit color displays.
-                if (1 != sscanf (line + 12, "%lx", &trans_color)) {
+                if (1 != sscanf (line + 12, "%lx", &temp_trans_color)) {
                     fprintf(stderr,"draw_geo_image_map:sscanf parsing error\n");
                 }
 
                 {
                     unsigned short r,g,b;
-                    // We'll assume the trans_color has been specified as a 
-                    // 24-bit quantity
-                    r = (trans_color&0xff0000) >> 16;
-                    g = (trans_color&0x00ff00)>>8;
-                    b = trans_color&0x0000ff;
+                    // We'll assume the temp_trans_color has been
+                    // specified as a 24-bit quantity
+                    r = (temp_trans_color&0xff0000) >> 16;
+                    g = (temp_trans_color&0x00ff00)>>8;
+                    b = temp_trans_color&0x0000ff;
                     // Now this is an incredible kludge, but seems to be right
                     // Apparently, if QuantumDepth is 16 bits, r, g, and b
                     // values are duplicated in the high and low byte, which
@@ -745,7 +836,7 @@ void draw_geo_image_map (Widget w,
                         b=b|(b<<8);
                     }
 #endif  // HAVE_MAGICK
-                    //fprintf(stderr,"Original Transparent %lx\n",trans_color);
+                    //fprintf(stderr,"Original Transparent %lx\n",temp_trans_color);
                     //fprintf(stderr,"Transparent r,g,b=%x,%x,%x\n",r,g,b);
                     if (visual_type == NOT_TRUE_NOR_DIRECT) {
                         XColor junk;
@@ -764,15 +855,17 @@ void draw_geo_image_map (Widget w,
                             junk.blue = b<<8;
                         }
                         XAllocColor(XtDisplay(w),cmap,&junk);
-                        trans_color = junk.pixel;
+                        temp_trans_color = junk.pixel;
                     } else {
-                        pack_pixel_bits(r,g,b,&trans_color);
+                        pack_pixel_bits(r,g,b,&temp_trans_color);
                     }
-                    //fprintf(stderr,"Packed Transparent %lx\n",trans_color);
+                    //fprintf(stderr,"Packed Transparent %lx\n",temp_trans_color);
                 }
 
-                do_check_trans = 1;
-//fprintf(stderr,"New Transparent: %lx\n",trans_color);
+//fprintf(stderr,"New Transparent: %lx\n",temp_trans_color);
+
+                // Link color to transparent color list
+                new_trans_color(temp_trans_color);
             }
             if (strncasecmp(line, "CROP", 4) == 0) { 
                 if (4 != sscanf (line + 5, "%d %d %d %d", 
@@ -867,8 +960,7 @@ void draw_geo_image_map (Widget w,
             filenm,
             destination_pixmap,
             fileimg,
-            do_check_trans,
-            trans_color,
+            trans_color_head,
             nocache); // Don't use cached version if non-zero
 
 #endif  // HAVE_MAGICK
@@ -1251,6 +1343,7 @@ fprintf(stderr,"1 ");
                 DestroyImage(image);
             if (image_info)
                 DestroyImageInfo(image_info);
+            DestroyExceptionInfo(&exception);
 #endif // HAVE_MAGICK
         }
     }
@@ -1458,12 +1551,14 @@ fprintf(stderr,"1 ");
                     get_user_base_dir("tmp"),ext);
             }
             else {
+                cache_file_id = map_cache_fileid();
                 xastir_snprintf(local_filename,
                     sizeof(local_filename),
                     "%s/map_%s.%s",
                     get_user_base_dir("map_cache"),
-                    map_cache_fileid(),
+                    cache_file_id,
                     ext);
+                free(cache_file_id);
             }
 
 #else   // USE_MAP_CACHE
@@ -1595,31 +1690,16 @@ fprintf(stderr,"2 ");
             DestroyImage(image);
         if (image_info)
             DestroyImageInfo(image_info);
+        DestroyExceptionInfo(&exception);
         return;
     }
 
     width = image->columns;
     height = image->rows;
 
-    HandlePendingEvents(app_context);
-    if (interrupt_drawing_now) {
-        if (image)
-            DestroyImage(image);
-        if (image_info)
-            DestroyImageInfo(image_info);
-        // Update to screen
-        (void)XCopyArea(XtDisplay(da),
-            pixmap,
-            XtWindow(da),
-            gc,
-            0,
-            0,
-            (unsigned int)screen_width,
-            (unsigned int)screen_height,
-            0,
-            0);
-        return;
-    }
+    if (check_interrupt(image, image_info, 
+	&exception, &da, &pixmap, &gc, screen_width, screen_height))
+	return;
 
     // gamma setup
     if (imagemagick_options.gamma_flag == 0 ||
@@ -1653,25 +1733,9 @@ fprintf(stderr,"2 ");
     else
         imagemagick_options.gamma_flag = 0;
 
-    HandlePendingEvents(app_context);
-    if (interrupt_drawing_now) {
-        if (image) 
-            DestroyImage(image);
-        if (image_info)
-            DestroyImageInfo(image_info);
-        // Update to screen
-        (void)XCopyArea(XtDisplay(da),
-            pixmap,
-            XtWindow(da),
-            gc,
-            0,
-            0,
-            (unsigned int)screen_width,
-            (unsigned int)screen_height,
-            0,
-            0);
-        return;
-    }
+    if (check_interrupt(image, image_info, 
+	&exception, &da, &pixmap, &gc, screen_width, screen_height))
+	return;
 
     if (imagemagick_options.gamma_flag) {
         if (debug_level & 16)
@@ -1679,25 +1743,9 @@ fprintf(stderr,"2 ");
         GammaImage(image, gamma);
     }
 
-    HandlePendingEvents(app_context);
-    if (interrupt_drawing_now) {
-        if (image) 
-            DestroyImage(image);
-        if (image_info)
-            DestroyImageInfo(image_info);
-        // Update to screen
-        (void)XCopyArea(XtDisplay(da),
-            pixmap,
-            XtWindow(da),
-            gc,
-            0,
-            0,
-            (unsigned int)screen_width,
-            (unsigned int)screen_height,
-            0,
-            0);
-        return;
-    }
+    if (check_interrupt(image, image_info, 
+	&exception, &da, &pixmap, &gc, screen_width, screen_height))
+	return;
 
     if (imagemagick_options.contrast != 0) {
         if (debug_level & 16)
@@ -1705,25 +1753,9 @@ fprintf(stderr,"2 ");
         ContrastImage(image, imagemagick_options.contrast);
     }
 
-    HandlePendingEvents(app_context);
-    if (interrupt_drawing_now) {
-        if (image) 
-            DestroyImage(image);
-        if (image_info)
-            DestroyImageInfo(image_info);
-        // Update to screen
-        (void)XCopyArea(XtDisplay(da),
-            pixmap,
-            XtWindow(da),
-            gc,
-            0,
-            0,
-            (unsigned int)screen_width,
-            (unsigned int)screen_height,
-            0,
-            0);
-        return;
-    }
+    if (check_interrupt(image, image_info, 
+	&exception, &da, &pixmap, &gc, screen_width, screen_height))
+	return;
 
     if (imagemagick_options.negate != -1) {
         if (debug_level & 16)
@@ -1731,25 +1763,9 @@ fprintf(stderr,"2 ");
         NegateImage(image, imagemagick_options.negate);
     }
 
-    HandlePendingEvents(app_context);
-    if (interrupt_drawing_now) {
-        if (image) 
-            DestroyImage(image);
-        if (image_info)
-            DestroyImageInfo(image_info);
-        // Update to screen
-        (void)XCopyArea(XtDisplay(da),
-            pixmap,
-            XtWindow(da),
-            gc,
-            0,
-            0,
-            (unsigned int)screen_width,
-            (unsigned int)screen_height,
-            0,
-            0);
-        return;
-    }
+    if (check_interrupt(image, image_info, 
+	&exception, &da, &pixmap, &gc, screen_width, screen_height))
+	return;
 
     if (imagemagick_options.equalize) {
         if (debug_level & 16)
@@ -1757,25 +1773,9 @@ fprintf(stderr,"2 ");
         EqualizeImage(image);
     }
 
-    HandlePendingEvents(app_context);
-    if (interrupt_drawing_now) {
-        if (image) 
-            DestroyImage(image);
-        if (image_info)
-            DestroyImageInfo(image_info);
-        // Update to screen
-        (void)XCopyArea(XtDisplay(da),
-            pixmap,
-            XtWindow(da),
-            gc,
-            0,
-            0,
-            (unsigned int)screen_width,
-            (unsigned int)screen_height,
-            0,
-            0);
-        return;
-    }
+    if (check_interrupt(image, image_info, 
+	&exception, &da, &pixmap, &gc, screen_width, screen_height))
+	return;
 
     if (imagemagick_options.normalize) {
         if (debug_level & 16)
@@ -1783,25 +1783,9 @@ fprintf(stderr,"2 ");
         NormalizeImage(image);
     }
 
-    HandlePendingEvents(app_context);
-    if (interrupt_drawing_now) {
-        if (image) 
-            DestroyImage(image);
-        if (image_info)
-            DestroyImageInfo(image_info);
-        // Update to screen
-        (void)XCopyArea(XtDisplay(da),
-            pixmap,
-            XtWindow(da),
-            gc,
-            0,
-            0,
-            (unsigned int)screen_width,
-            (unsigned int)screen_height,
-            0,
-            0);
-        return;
-    }
+    if (check_interrupt(image, image_info, 
+	&exception, &da, &pixmap, &gc, screen_width, screen_height))
+	return;
 
 #if (MagickLibVersion >= 0x0539)
     if (imagemagick_options.level[0] != '\0') {
@@ -1811,25 +1795,9 @@ fprintf(stderr,"2 ");
     }
 #endif  // MagickLibVersion >= 0x0539
 
-    HandlePendingEvents(app_context);
-    if (interrupt_drawing_now) {
-        if (image) 
-            DestroyImage(image);
-        if (image_info)
-            DestroyImageInfo(image_info);
-        // Update to screen
-        (void)XCopyArea(XtDisplay(da),
-            pixmap,
-            XtWindow(da),
-            gc,
-            0,
-            0,
-            (unsigned int)screen_width,
-            (unsigned int)screen_height,
-            0,
-            0);
-        return;
-    }
+    if (check_interrupt(image, image_info, 
+	&exception, &da, &pixmap, &gc, screen_width, screen_height))
+	return;
 
     if (imagemagick_options.modulate[0] != '\0') {
         if (debug_level & 16)
@@ -1855,25 +1823,9 @@ fprintf(stderr,"2 ");
     }
 */
 
-    HandlePendingEvents(app_context);
-    if (interrupt_drawing_now) {
-        if (image) 
-            DestroyImage(image);
-        if (image_info)
-            DestroyImageInfo(image_info);
-        // Update to screen
-        (void)XCopyArea(XtDisplay(da),
-            pixmap,
-            XtWindow(da),
-            gc,
-            0,
-            0,
-            (unsigned int)screen_width,
-            (unsigned int)screen_height,
-            0,
-            0);
-        return;
-    }
+    if (check_interrupt(image, image_info, 
+	&exception, &da, &pixmap, &gc, screen_width, screen_height))
+	return;
 
     // crop image: if we just use CropImage(), then the tiepoints will be off
     // make border pixels transparent.  
@@ -1898,7 +1850,8 @@ fprintf(stderr,"2 ");
             }
             if (!SyncImagePixels(image))
                 fprintf(stderr, "SyncImagePixels Failed....\n");
-        }
+	}
+        DestroyImagePixels(image);
     }
 
     // If were are drawing to a low bpp display (typically < 8bpp)
@@ -1922,25 +1875,9 @@ fprintf(stderr,"2 ");
         // Quantize down to 128 will go here...
     }
 
-    HandlePendingEvents(app_context);
-    if (interrupt_drawing_now) {
-        if (image) 
-            DestroyImage(image);
-        if (image_info)
-            DestroyImageInfo(image_info);
-        // Update to screen
-        (void)XCopyArea(XtDisplay(da),
-            pixmap,
-            XtWindow(da),
-            gc,
-            0,
-            0,
-            (unsigned int)screen_width,
-            (unsigned int)screen_height,
-            0,
-            0);
-        return;
-    }
+    if (check_interrupt(image, image_info, 
+	&exception, &da, &pixmap, &gc, screen_width, screen_height))
+	return;
 
     pixel_pack = GetImagePixels(image, 0, 0, image->columns, image->rows);
     if (!pixel_pack) {
@@ -1949,28 +1886,13 @@ fprintf(stderr,"2 ");
             DestroyImage(image);
         if (image_info)
             DestroyImageInfo(image_info);
-        return;
+       DestroyExceptionInfo(&exception);
+         return;
     }
 
-    HandlePendingEvents(app_context);
-    if (interrupt_drawing_now) {
-        if (image) 
-            DestroyImage(image);
-        if (image_info)
-            DestroyImageInfo(image_info);
-        // Update to screen
-        (void)XCopyArea(XtDisplay(da),
-            pixmap,
-            XtWindow(da),
-            gc,
-            0,
-            0,
-            (unsigned int)screen_width,
-            (unsigned int)screen_height,
-            0,
-            0);
-        return;
-    }
+    if (check_interrupt(image, image_info, 
+	&exception, &da, &pixmap, &gc, screen_width, screen_height))
+	return;
 
     index_pack = GetIndexes(image);
     if (image->storage_class == PseudoClass && !index_pack) {
@@ -1982,25 +1904,9 @@ fprintf(stderr,"2 ");
         return;
     }
 
-    HandlePendingEvents(app_context);
-    if (interrupt_drawing_now) {
-        if (image) 
-            DestroyImage(image);
-        if (image_info)
-            DestroyImageInfo(image_info);
-        // Update to screen
-        (void)XCopyArea(XtDisplay(da),
-            pixmap,
-            XtWindow(da),
-            gc,
-            0,
-            0,
-            (unsigned int)screen_width,
-            (unsigned int)screen_height,
-            0,
-            0);
-        return;
-    }
+    if (check_interrupt(image, image_info, 
+	&exception, &da, &pixmap, &gc, screen_width, screen_height))
+	return;
 
     if (debug_level & 16)
 #ifdef HAVE_GRAPHICSMAGICK
@@ -2046,7 +1952,7 @@ fprintf(stderr,"2 ");
 
             // Take care not to screw up the transparency value by
             // the raster_map_intensity multiplication factor.
-            if ( do_check_trans ) {
+            if ( trans_color_head ) {
 //fprintf(stderr,"Checking for transparency\n");
 
                 // Get the color allocated on < 8bpp displays. pixel color is written to my_colors.pixel
@@ -2059,7 +1965,7 @@ fprintf(stderr,"2 ");
                                     &my_colors[l].pixel);
                 }
 
-                if (check_trans(my_colors[l],trans_color) ) {
+                if (check_trans(my_colors[l],trans_color_head) ) {
 
                     // Found a transparent color.  Leave it alone.
                     leave_unchanged++;
@@ -2093,25 +1999,9 @@ fprintf(stderr,"2 ");
         }
     }
 
-    HandlePendingEvents(app_context);
-    if (interrupt_drawing_now) {
-        if (image) 
-            DestroyImage(image);
-        if (image_info)
-            DestroyImageInfo(image_info);
-        // Update to screen
-        (void)XCopyArea(XtDisplay(da),
-            pixmap,
-            XtWindow(da),
-            gc,
-            0,
-            0,
-            (unsigned int)screen_width,
-            (unsigned int)screen_height,
-            0,
-            0);
-        return;
-    }
+    if (check_interrupt(image, image_info, 
+	&exception, &da, &pixmap, &gc, screen_width, screen_height))
+	return;
 
 #ifdef TIMING_DEBUG
     time_mark(0);
@@ -2309,30 +2199,14 @@ fprintf(stderr,"2 ");
 #endif  // TIMING_DEBUG
 
 
-    HandlePendingEvents(app_context);
-    if (interrupt_drawing_now) {
+    if (check_interrupt(
 #ifdef HAVE_MAGICK
-        if (image)
-            DestroyImage(image);
-        if (image_info)
-            DestroyImageInfo(image_info);
-#else   // HAVE_MAGICK
-        if (xi)
-            XDestroyImage (xi);
-#endif  // HAVE_MAGICK
-        // Update to screen
-        (void)XCopyArea(XtDisplay(da),
-            pixmap,
-            XtWindow(da),
-            gc,
-            0,
-            0,
-            (unsigned int)screen_width,
-            (unsigned int)screen_height,
-            0,
-            0);
-        return;
-    }
+			image, image_info, &exception, 
+#else  // HAVE_MAGICK
+            		xi,
+#endif // HAVE_MAGICK
+			&da, &pixmap, &gc, screen_width, screen_height))
+	return;
 
 
     // loop over map pixel rows
@@ -2340,30 +2214,14 @@ fprintf(stderr,"2 ");
                 (map_y_0 <= map_y_max) || (map_proj == 1 && !map_done && scr_y < screen_height);
                 map_y_0++, c_y += map_c_dy) {
 
-        HandlePendingEvents(app_context);
-        if (interrupt_drawing_now) {
+    if (check_interrupt(
 #ifdef HAVE_MAGICK
-            if (image)
-                DestroyImage(image);
-            if (image_info)
-                DestroyImageInfo(image_info);
-#else   // HAVE_MAGICK
-            if (xi)
-                XDestroyImage (xi);
+			image, image_info, &exception, 
+#else  // HAVE_MAGICK
+            		xi,
 #endif // HAVE_MAGICK
-            // Update to screen
-            (void)XCopyArea(XtDisplay(da),
-                pixmap,
-                XtWindow(da),
-                gc,
-                0,
-                0,
-                (unsigned int)screen_width,
-                (unsigned int)screen_height,
-                0,
-                0);
-            return;
-        }
+			&da, &pixmap, &gc, screen_width, screen_height))
+	return;
 
         scr_y = (c_y - NW_corner_latitude) / scale_y;
         if (scr_y != scr_yp) {                  // don't do a row twice
@@ -2434,8 +2292,8 @@ fprintf(stderr,"2 ");
                         l = map_x + map_y * image->columns;
                         trans_skip = 1; // possibly transparent
                         if (image->storage_class == PseudoClass) {
-                            if ( do_check_trans && 
-                                    check_trans(my_colors[index_pack[l]],trans_color) ) {
+                            if ( trans_color_head && 
+                                    check_trans(my_colors[index_pack[l]],trans_color_head) ) {
                                 trans_skip = 1; // skip it
                             }
                             else {
@@ -2447,8 +2305,8 @@ fprintf(stderr,"2 ");
                                             pixel_pack[l].green * raster_map_intensity,
                                             pixel_pack[l].blue * raster_map_intensity,
                                             &my_colors[0].pixel);
-                            if ( do_check_trans && 
-                                    check_trans(my_colors[0],trans_color) ) {
+                            if ( trans_color_head && 
+                                    check_trans(my_colors[0],trans_color_head) ) {
                                 trans_skip = 1; // skip it
                             }
                             else {
@@ -2482,7 +2340,8 @@ fprintf(stderr,"2 ");
         DestroyImage(image);
     if (image_info)
         DestroyImageInfo(image_info);
-#else   // HAVE_MAGICK
+    DestroyExceptionInfo(&exception);
+ #else   // HAVE_MAGICK
     if (xi)
         XDestroyImage (xi);
 #endif // HAVE_MAGICK
