@@ -1,5 +1,5 @@
 /* -*- c-basic-offset: 4; indent-tabs-mode: nil -*-
- * $Id: index.c,v 1.6 2007/01/03 19:38:41 we7u Exp $
+ * $Id: index.c,v 1.7 2007/07/02 23:37:48 tvrusso Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
@@ -41,10 +41,10 @@
 
 // Make a new index, empty.  Consists of a single node.
 //
-struct Node * RTreeNewIndex(void)
+struct Node * Xastir_RTreeNewIndex(void)
 {
 	struct Node *x;
-	x = RTreeNewNode();
+	x = Xastir_RTreeNewNode();
 	x->level = 0; /* leaf */
 	return x;
 }
@@ -55,7 +55,7 @@ struct Node * RTreeNewIndex(void)
 // overlap the argument rectangle.
 // Return the number of qualifying data rects.
 //
-int RTreeSearch(struct Node *N, struct Rect *R, SearchHitCallback shcb, void* cbarg)
+int Xastir_RTreeSearch(struct Node *N, struct Rect *R, SearchHitCallback shcb, void* cbarg)
 {
 	register struct Node *n = N;
 	register struct Rect *r = R; // NOTE: Suspected bug was R sent in as Node* and cast to Rect* here. Fix not yet tested.
@@ -68,18 +68,18 @@ int RTreeSearch(struct Node *N, struct Rect *R, SearchHitCallback shcb, void* cb
 
 	if (n->level > 0) /* this is an internal node in the tree */
 	{
-		for (i=0; i<NODECARD; i++)
+		for (i=0; i<Xastir_NODECARD; i++)
 			if (n->branch[i].child &&
-			    RTreeOverlap(r,&n->branch[i].rect))
+			    Xastir_RTreeOverlap(r,&n->branch[i].rect))
 			{
-				hitCount += RTreeSearch(n->branch[i].child, R, shcb, cbarg);
+				hitCount += Xastir_RTreeSearch(n->branch[i].child, R, shcb, cbarg);
 			}
 	}
 	else /* this is a leaf node */
 	{
-		for (i=0; i<LEAFCARD; i++)
+		for (i=0; i<Xastir_LEAFCARD; i++)
 			if (n->branch[i].child &&
-			    RTreeOverlap(r,&n->branch[i].rect))
+			    Xastir_RTreeOverlap(r,&n->branch[i].rect))
 			{
 				hitCount++;
 				if(shcb) // call the user-provided callback
@@ -100,7 +100,7 @@ int RTreeSearch(struct Node *N, struct Rect *R, SearchHitCallback shcb, void* cb
 // The level argument specifies the number of steps up from the leaf
 // level to insert; e.g. a data rectangle goes in at level = 0.
 //
-static int RTreeInsertRect2(struct Rect *r,
+static int Xastir_RTreeInsertRect2(struct Rect *r,
 		int tid, struct Node *n, struct Node **new_node, int level)
 {
 /*
@@ -121,21 +121,21 @@ static int RTreeInsertRect2(struct Rect *r,
 	//
 	if (n->level > level)
 	{
-		i = RTreePickBranch(r, n);
-		if (!RTreeInsertRect2(r, tid, n->branch[i].child, &n2, level))
+		i = Xastir_RTreePickBranch(r, n);
+		if (!Xastir_RTreeInsertRect2(r, tid, n->branch[i].child, &n2, level))
 		{
 			// child was not split
 			//
 			n->branch[i].rect =
-				RTreeCombineRect(r,&(n->branch[i].rect));
+				Xastir_RTreeCombineRect(r,&(n->branch[i].rect));
 			return 0;
 		}
 		else    // child was split
 		{
-			n->branch[i].rect = RTreeNodeCover(n->branch[i].child);
+			n->branch[i].rect = Xastir_RTreeNodeCover(n->branch[i].child);
 			b.child = n2;
-			b.rect = RTreeNodeCover(n2);
-			return RTreeAddBranch(&b, n, new_node);
+			b.rect = Xastir_RTreeNodeCover(n2);
+			return Xastir_RTreeAddBranch(&b, n, new_node);
 		}
 	}
 
@@ -146,7 +146,7 @@ static int RTreeInsertRect2(struct Rect *r,
 		b.rect = *r;
 		b.child = (struct Node *) tid;
 		/* child field of leaves contains tid of data record */
-		return RTreeAddBranch(&b, n, new_node);
+		return Xastir_RTreeAddBranch(&b, n, new_node);
 	}
 	else
 	{
@@ -159,13 +159,13 @@ static int RTreeInsertRect2(struct Rect *r,
 
 
 // Insert a data rectangle into an index structure.
-// RTreeInsertRect provides for splitting the root;
+// Xastir_RTreeInsertRect provides for splitting the root;
 // returns 1 if root was split, 0 if it was not.
 // The level argument specifies the number of steps up from the leaf
 // level to insert; e.g. a data rectangle goes in at level = 0.
-// RTreeInsertRect2 does the recursion.
+// Xastir_RTreeInsertRect2 does the recursion.
 //
-int RTreeInsertRect(struct Rect *R, int Tid, struct Node **Root, int Level)
+int Xastir_RTreeInsertRect(struct Rect *R, int Tid, struct Node **Root, int Level)
 {
 	register struct Rect *r = R;
 	register int tid = Tid;
@@ -182,16 +182,16 @@ int RTreeInsertRect(struct Rect *R, int Tid, struct Node **Root, int Level)
 	for (i=0; i<NUMDIMS; i++)
 		assert(r->boundary[i] <= r->boundary[NUMDIMS+i]);
 
-	if (RTreeInsertRect2(r, tid, *root, &newnode, level))  /* root split */
+	if (Xastir_RTreeInsertRect2(r, tid, *root, &newnode, level))  /* root split */
 	{
-		newroot = RTreeNewNode();  /* grow a new root, & tree taller */
+		newroot = Xastir_RTreeNewNode();  /* grow a new root, & tree taller */
 		newroot->level = (*root)->level + 1;
-		b.rect = RTreeNodeCover(*root);
+		b.rect = Xastir_RTreeNodeCover(*root);
 		b.child = *root;
-		RTreeAddBranch(&b, newroot, NULL);
-		b.rect = RTreeNodeCover(newnode);
+		Xastir_RTreeAddBranch(&b, newroot, NULL);
+		b.rect = Xastir_RTreeNodeCover(newnode);
 		b.child = newnode;
-		RTreeAddBranch(&b, newroot, NULL);
+		Xastir_RTreeAddBranch(&b, newroot, NULL);
 		*root = newroot;
 		result = 1;
 	}
@@ -207,14 +207,14 @@ int RTreeInsertRect(struct Rect *R, int Tid, struct Node **Root, int Level)
 // Allocate space for a node in the list used in DeletRect to
 // store Nodes that are too empty.
 //
-static struct ListNode * RTreeNewListNode(void)
+static struct ListNode * Xastir_RTreeNewListNode(void)
 {
 	return (struct ListNode *) malloc(sizeof(struct ListNode));
 	//return new ListNode;
 }
 
 
-static void RTreeFreeListNode(struct ListNode *p)
+static void Xastir_RTreeFreeListNode(struct ListNode *p)
 {
 	free(p);
 	//delete(p);
@@ -225,11 +225,11 @@ static void RTreeFreeListNode(struct ListNode *p)
 // Add a node to the reinsertion list.  All its branches will later
 // be reinserted into the index structure.
 //
-static void RTreeReInsert(struct Node *n, struct ListNode **ee)
+static void Xastir_RTreeReInsert(struct Node *n, struct ListNode **ee)
 {
 	register struct ListNode *l;
 
-	l = RTreeNewListNode();
+	l = Xastir_RTreeNewListNode();
 	l->node = n;
 	l->next = *ee;
 	*ee = l;
@@ -237,12 +237,12 @@ static void RTreeReInsert(struct Node *n, struct ListNode **ee)
 
 
 // Delete a rectangle from non-root part of an index structure.
-// Called by RTreeDeleteRect.  Descends tree recursively,
+// Called by Xastir_RTreeDeleteRect.  Descends tree recursively,
 // merges branches on the way back up.
 // Returns 1 if record not found, 0 if success.
 //
 static int
-RTreeDeleteRect2(struct Rect *R, int Tid, struct Node *N, struct ListNode **Ee)
+Xastir_RTreeDeleteRect2(struct Rect *R, int Tid, struct Node *N, struct ListNode **Ee)
 {
 	register struct Rect *r = R;
 	register int tid = Tid;
@@ -256,22 +256,22 @@ RTreeDeleteRect2(struct Rect *R, int Tid, struct Node *N, struct ListNode **Ee)
 
 	if (n->level > 0)  // not a leaf node
 	{
-	    for (i = 0; i < NODECARD; i++)
+	    for (i = 0; i < Xastir_NODECARD; i++)
 	    {
-		if (n->branch[i].child && RTreeOverlap(r, &(n->branch[i].rect)))
+		if (n->branch[i].child && Xastir_RTreeOverlap(r, &(n->branch[i].rect)))
 		{
-			if (!RTreeDeleteRect2(r, tid, n->branch[i].child, ee))
+			if (!Xastir_RTreeDeleteRect2(r, tid, n->branch[i].child, ee))
 			{
 				if (n->branch[i].child->count >= MinNodeFill)
-					n->branch[i].rect = RTreeNodeCover(
+					n->branch[i].rect = Xastir_RTreeNodeCover(
 						n->branch[i].child);
 				else
 				{
 					// not enough entries in child,
 					// eliminate child node
 					//
-					RTreeReInsert(n->branch[i].child, ee);
-					RTreeDisconnectBranch(n, i);
+					Xastir_RTreeReInsert(n->branch[i].child, ee);
+					Xastir_RTreeDisconnectBranch(n, i);
 				}
 				return 0;
 			}
@@ -281,12 +281,12 @@ RTreeDeleteRect2(struct Rect *R, int Tid, struct Node *N, struct ListNode **Ee)
 	}
 	else  // a leaf node
 	{
-		for (i = 0; i < LEAFCARD; i++)
+		for (i = 0; i < Xastir_LEAFCARD; i++)
 		{
 			if (n->branch[i].child &&
 			    n->branch[i].child == (struct Node *) tid)
 			{
-				RTreeDisconnectBranch(n, i);
+				Xastir_RTreeDisconnectBranch(n, i);
 				return 0;
 			}
 		}
@@ -299,9 +299,9 @@ RTreeDeleteRect2(struct Rect *R, int Tid, struct Node *N, struct ListNode **Ee)
 // Delete a data rectangle from an index structure.
 // Pass in a pointer to a Rect, the tid of the record, ptr to ptr to root node.
 // Returns 1 if record not found, 0 if success.
-// RTreeDeleteRect provides for eliminating the root.
+// Xastir_RTreeDeleteRect provides for eliminating the root.
 //
-int RTreeDeleteRect(struct Rect *R, int Tid, struct Node**Nn)
+int Xastir_RTreeDeleteRect(struct Rect *R, int Tid, struct Node**Nn)
 {
 	register struct Rect *r = R;
 	register int tid = Tid;
@@ -319,7 +319,7 @@ int RTreeDeleteRect(struct Rect *R, int Tid, struct Node**Nn)
 	assert(*nn);
 	assert(tid >= 0);
 
-	if (!RTreeDeleteRect2(r, tid, *nn, &reInsertList))
+	if (!Xastir_RTreeDeleteRect2(r, tid, *nn, &reInsertList))
 	{
 		/* found and deleted a data item */
 
@@ -331,7 +331,7 @@ int RTreeDeleteRect(struct Rect *R, int Tid, struct Node**Nn)
 			{
 				if (tmp_nptr->branch[i].child)
 				{
-					RTreeInsertRect(
+					Xastir_RTreeInsertRect(
 						&(tmp_nptr->branch[i].rect),
 						(int)tmp_nptr->branch[i].child,
 						nn,
@@ -340,22 +340,22 @@ int RTreeDeleteRect(struct Rect *R, int Tid, struct Node**Nn)
 			}
 			e = reInsertList;
 			reInsertList = reInsertList->next;
-			RTreeFreeNode(e->node);
-			RTreeFreeListNode(e);
+			Xastir_RTreeFreeNode(e->node);
+			Xastir_RTreeFreeListNode(e);
 		}
 		
 		/* check for redundant root (not leaf, 1 child) and eliminate
 		*/
 		if ((*nn)->count == 1 && (*nn)->level > 0)
 		{
-			for (i = 0; i < NODECARD; i++)
+			for (i = 0; i < Xastir_NODECARD; i++)
 			{
 				tmp_nptr = (*nn)->branch[i].child;
 				if(tmp_nptr)
 					break;
 			}
 			assert(tmp_nptr);
-			RTreeFreeNode(*nn);
+			Xastir_RTreeFreeNode(*nn);
 			*nn = tmp_nptr;
 		}
 		return 0;
