@@ -1,5 +1,5 @@
 /*
- * $Id: track_gui.c,v 1.62 2007/01/03 19:39:12 we7u Exp $
+ * $Id: track_gui.c,v 1.66 2007/09/25 02:41:31 we7u Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
@@ -413,6 +413,7 @@ end_critical_section(&track_station_dialog_lock, "track_gui.c:Track_station" );
 static void* findu_transfer_thread(void *arg) {
     char *fileimg;
     char *log_filename;
+//    char log_filename_tmp[210];
     char **ptrs;
     char sys_cmd[128];
 
@@ -462,18 +463,95 @@ static void* findu_transfer_thread(void *arg) {
     // Set permissions on the file so that any user can overwrite it.
     chmod(log_filename, 0666);
 
-    // Add three spaces before the "<br" on each line.  This is so
-    // that Base-91 compressed packets with no comment and no
+    // Add three spaces before each "<br>" and axe the "<br>".  This
+    // is so that Base-91 compressed packets with no comment and no
     // speed/course/altitude will get decoded ok.  Otherwise the
     // spaces that are critical to the Base-91 packets won't be
     // there due to findu.com filtering them out.
     //
+// "sed -i -e \"s/<br>/   <br>/\" %s",
     sprintf(sys_cmd,
-        "sed -i -e \"s/<br>/   <br>/\" %s",
+        "sed -i -e \"s/<br>/   /\" %s",
         log_filename);
     system(sys_cmd);
 //fprintf(stderr,"%s\n", sys_cmd);
 
+// Greater-than symbol '>'
+    sprintf(sys_cmd,
+        "sed -i -e \"s/&gt;/>/\" %s",
+        log_filename);
+    system(sys_cmd);
+
+// Less-than symbol '<'
+    sprintf(sys_cmd,
+        "sed -i -e \"s/&lt;/</\" %s",
+        log_filename);
+    system(sys_cmd);
+
+// Ampersand '&' (A difficult character to escape from the shell!)
+    sprintf(sys_cmd,
+        "sed -i -e \"s/&amp;/\\&/\" %s",
+        log_filename);
+    system(sys_cmd);
+
+// Double-quote symbol '"'
+    sprintf(sys_cmd,
+        "sed -i -e \"s/&quot;/""/\" %s",
+        log_filename);
+    system(sys_cmd);
+
+// Remove whitespace at the start of a line
+// sed 's/^[ \t]*//'
+    sprintf(sys_cmd,
+        "sed -i -e \"s/^[ \t]*//\" %s",
+        log_filename);
+    system(sys_cmd);
+
+// Remove any lines that start with '<'
+    sprintf(sys_cmd,
+        "sed -i -e \"s/^<.*$//\" %s",
+        log_filename);
+    system(sys_cmd);
+
+// Remove any lines that start with '"http'
+    sprintf(sys_cmd,
+        "sed -i -e \"/^\\\"http.*$/d\" %s",
+        log_filename);
+    system(sys_cmd);
+
+// Remove any blank lines from the file
+// sed '/^$/d'
+    sprintf(sys_cmd,
+        "sed -i -e \"/^$/d\" %s",
+        log_filename);
+    system(sys_cmd);
+
+
+/*
+#ifdef HAVE_HTML2TEXT
+    // Create temp filename
+    snprintf(log_filename_tmp, sizeof(log_filename_tmp), "%s%s",
+        log_filename,
+        ".tmp");
+    // Create html2text command
+    sprintf(sys_cmd,
+        "%s -width 300 -o %s %s",
+        HTML2TEXT_PATH,
+        log_filename_tmp,
+        log_filename);
+    // Convert the newly-downloaded file from html to text format
+    system(sys_cmd);
+    // Rename the file so that we can keep the static char* name
+    // pointing to it, needed for the read_file_ptr code in the main
+    // thread.
+    sprintf(sys_cmd,
+        "mv %s %s",
+        log_filename_tmp,
+        log_filename);
+    system(sys_cmd);
+#endif  // HAVE_HTML2TEXT
+*/
+
     // Here we do the findu stuff, if the findu_flag is set.  Else we do an imagemap.
     // We have the log data we're interested in within the log_filename file.
     // Cause that file to be read by the "File->Open Log File" routine.  HTML
