@@ -1,5 +1,5 @@
 /*
- * $Id: util.h,v 1.51 2007/01/03 19:39:13 we7u Exp $
+ * $Id: util.h,v 1.53 2007/08/07 01:06:34 chicoreus Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
@@ -70,6 +70,7 @@ extern void start_timer(void);
 extern void stop_timer(void);
 extern void print_timer_results(void);
 extern void get_timestamp(char *timestring);
+extern int get_iso_datetime(time_t aTime, char *timestring, int nowIfNotSet, int nowIfInvalid);
 extern int get_hours(void);
 extern int get_minutes(void);
 extern int get_seconds(void);
@@ -169,6 +170,9 @@ extern void set_dangerous( char *ptr );
 extern void clear_dangerous(void);
 
 void xastirWriteWKT(char *name);
+char * makeMultiline(int numPairs, double *lon, double *lat, char colorStyle,
+                     int lineType, char* sqnc,
+                     double *lonCentr, double *latCentr );
 
 #endif // __XASTIR_UTIL_H
 
