@@ -1,5 +1,5 @@
 /*
- * $Id: x_spider.c,v 1.53 2007/01/03 19:39:13 we7u Exp $
+ * $Id: x_spider.c,v 1.57 2007/08/13 20:22:38 gstueve Exp $
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 2003-2007  The Xastir Group
@@ -759,17 +759,17 @@ line[n] = '\0';
         // off any line-end characters that might be present, then
         // add a "\r\n" combo on the end.
         //
-        if (line[n-1] == '\r' || line[n-1] == '\n') {
+        if (n >= 1 && (line[n-1] == '\r' || line[n-1] == '\n')) {
             line[n-1] = '\0';
             n--;
         }
-        if (line[n-1] == '\r' || line[n-1] == '\n') {
+        if (n >= 1 && (line[n-1] == '\r' || line[n-1] == '\n')) {
             line[n-1] = '\0';
             n--;
         }
         // Add carriage-return/linefeed onto the end
         strncat(line, "\r\n", 2);
-        n = n+2;
+        n += 2;
 
         while (q != NULL) {
 //          fprintf(stderr,"pipe_check: %s\n",line);
@@ -788,7 +788,7 @@ line[n] = '\0';
 
 
 
-// The below two functions init_set_proc_title() and
+// The below three functions init_set_proc_title() and
 // set_proc_title() are from:
 // http://lightconsulting.com/~thalakan/process-title-notes.html
 // They seems to work fine on Linux, but they only change the "ps"
@@ -797,6 +797,8 @@ line[n] = '\0';
 // Here's another good web page for Linux:
 // http://www.uwsg.iu.edu/hypermail/linux/kernel/0006.1/0610.html 
 
+// clear_proc_title is to clean up internal pointers for environment.
+
 /* Globals */
 static char **Argv = ((void *)0);
 #ifdef __linux__
@@ -805,12 +807,12 @@ extern char *__progname, *__progname_full;
 #endif  // __LSB__
 #endif  // __linux__
 static char *LastArgv = ((void *)0);
+extern char **environ;
 
 
 
 void init_set_proc_title(int argc, char *argv[], char *envp[]) {
     int i, envpsize;
-    extern char **environ;
     char **p;
 
     for(i = envpsize = 0; envp[i] != NULL; i++)
@@ -846,8 +848,14 @@ void init_set_proc_title(int argc, char *argv[], char *envp[]) {
 }
 
 
-
-
+void clear_proc_title(void)
+{
+  int i;
+  for(i = 0; environ[i] != NULL; i++) {
+    free(environ[i]);
+  }
+  free(environ);
+}
 
 void set_proc_title(char *fmt,...) {
     va_list msg;
@@ -872,6 +880,7 @@ void set_proc_title(char *fmt,...) {
     while(p < LastArgv)
         *p++ = '\0';
     Argv[1] = ((void *)0) ;
+    atexit(clear_proc_title);
 }
 
 
@@ -968,6 +977,7 @@ void TCP_Server(int argc, char *argv[], char *envp[]) {
     // service them).
     //
     listen(sockfd, 5);
+    memset((char *)&cli_addr, 0, sizeof(cli_addr));
 
     // Infinite loop
     //
@@ -1102,6 +1112,7 @@ void TCP_Server(int argc, char *argv[], char *envp[]) {
                 inet_ntoa(cli_addr.sin_addr),
                 "(xastir)");
             //fprintf(stderr,"DEBUG: %s\n", Argv[0]);
+	    (void) signal(SIGHUP, exit);
 #endif  // __linux__
 
 // It'd be very cool here to include the IP address of the remote
@@ -1481,6 +1492,7 @@ int Fork_TCP_server(int argc, char *argv[], char *envp[]) {
         init_set_proc_title(argc, argv, envp);
         set_proc_title("%s", "x-spider TCP daemon (xastir)");
         //fprintf(stderr,"DEBUG: %s\n", Argv[0]);
+	(void) signal(SIGHUP, exit);
 #endif  // __linux__
  
 
@@ -1597,6 +1609,7 @@ int Fork_UDP_server(int argc, char *argv[], char *envp[]) {
         init_set_proc_title(argc, argv, envp);
         set_proc_title("%s", "x-spider UDP daemon (xastir)");
         //fprintf(stderr,"DEBUG: %s\n", Argv[0]);
+	(void) signal(SIGHUP, exit);
 #endif  // __linux__
  
 
@@ -1620,9 +1633,9 @@ int Fork_UDP_server(int argc, char *argv[], char *envp[]) {
 //        while (1) {
 //            fprintf(stderr,"Starting UDP_Server...\n");
 
-            UDP_Server(argc, argv, envp);
+	UDP_Server(argc, argv, envp);
  
-            fprintf(stderr,"UDP_Server process died.\n");
+	fprintf(stderr,"UDP_Server process died.\n");
 //        }
     }
     //
